==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="vi" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Cài đặt chung</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Cài đặt OpenSCAD chung</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Có thể thực thi OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Nhập OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Sử dụng ViewProvider trong chế độ xem dạng cây</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Nếu chọn ô này, đối tượng Multmatrix sẽ là tham số</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Sử dụng tính năng Multmatrix</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Số lượng bề mặt tối đa của đa giác, lăng kính hoặc hình nón cụt. Nếu fn lớn hơn giá trị này thì đối tượng được coi là một vòng tròn. Đặt số 0 để không giới hạn</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Số lượng mặt tối đa cho đa giác (fn)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Xuất OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>kích thước đoạn tối đa</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>góc (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="../ui/openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>kích thước (fs)</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>lồi lõm</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Lưới dự phòng</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Độ lệch</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>độ lệch</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Cài đặt tam giác</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Nếu chọn ô này, các tính năng trong chế độ xem dạng cây sẽ được bao gồm trong các con của nó</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>In thông tin gỡ lỗi trong Bảng điều khiển</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Đường dẫn đến tệp thực thi OpenSCAD</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Góc tối thiểu cho một đoạn</translation>
    </message>
    <message>
      <location filename="../ui/openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Kích thước tối thiểu của một đoạn</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="145"/>
      <source>Convert Edges to Faces</source>
      <translation>Chuyển đổi các cạnh sang bề mặt</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="224"/>
      <source>Please select 3 objects first</source>
      <translation>Hãy chọn 3 đối tượng trước</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Unsupported Function</source>
      <translation>Chức năng không được hỗ trợ</translation>
    </message>
    <message>
      <location filename="../../importCSG.py" line="1204"/>
      <source>Press OK</source>
      <translation>Nhấn OK</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="268"/>
      <source>Add</source>
      <translation>Thêm mới</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="269"/>
      <source>Clear</source>
      <translation>Xóa</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="270"/>
      <source>as Mesh</source>
      <translation>như lưới</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="271"/>
      <source>Add OpenSCAD Element</source>
      <translation>Thêm phần tử OpenSCAD</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="344"/>
      <source>Perform</source>
      <translation>Thực hiện</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="345"/>
      <source>Mesh Boolean</source>
      <translation>Lưới Boolean</translation>
    </message>
    <message>
      <location filename="../../OpenSCADUtils.py" line="585"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Lỗi tất cả các hình dạng phải là 2D hoặc cả hai phải là 3D</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="95"/>
      <source>Unable to explode %s</source>
      <translation>Không thể kéo dài thêm %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="386"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Thêm phần tử OpenSCAD...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="388"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Thêm một phần tử OpenSCAD bằng cách nhập mã OpenSCAD và thực thi nhị phân OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="122"/>
      <source>Color Shapes</source>
      <translation>Hình dạng màu sắc</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="124"/>
      <source>Color Shapes by validity and type</source>
      <translation>Phân loại hình dạng màu theo giá trị và kiểu</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="143"/>
      <source>Convert Edges To Faces</source>
      <translation>Chuyển đổi các cạnh sang thành mặt</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="204"/>
      <source>Expand Placements</source>
      <translation>Mở rộng vị trí</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="206"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Mở rộng tất cả các vị trí xuống dưới FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="104"/>
      <source>Explode Group</source>
      <translation>Nhóm tháo rời</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="106"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Loại bỏ sáp nhập, áp dụng vị trí cho sản phẩm và tô màu một cách ngẫu nhiên</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="421"/>
      <source>Hull</source>
      <translation>Vỏ bọc</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="423"/>
      <source>Perform Hull</source>
      <translation>Xây dựng Vỏ bọc</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="185"/>
      <source>Increase Tolerance Feature</source>
      <translation>Tính năng tăng dung sai</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="187"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Tạo tính năng cho phép tăng dung sai</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="400"/>
      <source>Mesh Boolean...</source>
      <translation>Lưới Boolean...</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="402"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Xuất các đối tượng dưới dạng lưới và sử dụng OpenSCAD để thực hiện thao tác boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="442"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="444"/>
      <source>Perform Minkowski</source>
      <translation>Thực hiện Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="164"/>
      <source>Refine Shape Feature</source>
      <translation>Tính năng tinh chỉnh hình dạng</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="166"/>
      <source>Create Refine Shape Feature</source>
      <translation>Tạo tính năng tinh chỉnh hình dạng</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="243"/>
      <source>Remove Objects and their Children</source>
      <translation>Loại bỏ các đối tượng và sản phẩm của chúng</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="245"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Loại bỏ các đối tượng đã chọn và tất cả sản phẩm không được tham chiếu từ các đối tượng khác</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="../../OpenSCADCommands.py" line="228"/>
      <source>Replace Object</source>
      <translation>Thay thế đối tượng</translation>
    </message>
    <message>
      <location filename="../../OpenSCADCommands.py" line="230"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Thay thế một đối tượng trong cây tính năng. Vui lòng chọn đối tượng cũ, mới và gốc</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="../../InitGui.py" line="80"/>
      <source>OpenSCAD Part tools</source>
      <translation>Công cụ phần OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../InitGui.py" line="78"/>
      <source>OpenSCADTools</source>
      <translation>Công cụ OpenSCAD</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/OpenSCAD/Resources/translations/OpenSCAD_vi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="vi" sourcelanguage="en">
  <context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
      <location filename="openscadprefs-base.ui" line="14"/>
      <source>General settings</source>
      <translation>Cài đặt chung</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="26"/>
      <source>General OpenSCAD Settings</source>
      <translation>Cài đặt OpenSCAD chung</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="34"/>
      <source>OpenSCAD executable</source>
      <translation>Có thể thực thi OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="65"/>
      <source>OpenSCAD import</source>
      <translation>Nhập OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="93"/>
      <source>Use ViewProvider in Tree View</source>
      <translation>Sử dụng ViewProvider trong chế độ xem dạng cây</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="110"/>
      <source>If this is checked, Multmatrix Object will be Parametric</source>
      <translation>Nếu chọn ô này, đối tượng Multmatrix sẽ là tham số</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="113"/>
      <source>Use Multmatrix Feature</source>
      <translation>Sử dụng tính năng Multmatrix</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="153"/>
      <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
      <translation>Số lượng bề mặt tối đa của đa giác, lăng kính hoặc hình nón cụt. Nếu fn lớn hơn giá trị này thì đối tượng được coi là một vòng tròn. Đặt số 0 để không giới hạn</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="133"/>
      <source>Maximum number of faces for polygons (fn)</source>
      <translation>Số lượng mặt tối đa cho đa giác (fn)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="177"/>
      <source>OpenSCAD export</source>
      <translation>Xuất OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="185"/>
      <source>maximum fragment size</source>
      <translation>kích thước đoạn tối đa</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="208"/>
      <source>angular (fa)</source>
      <translation>góc (fa)</translation>
    </message>
    <message encoding="UTF-8">
      <location filename="openscadprefs-base.ui" line="218"/>
      <source>°</source>
      <translation>°</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="250"/>
      <source>size (fs)</source>
      <translation>kích thước (fs)</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="278"/>
      <source>mm</source>
      <translation>mm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="304"/>
      <source>convexity</source>
      <translation>lồi lõm</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="341"/>
      <source>Mesh fallback</source>
      <translation>Lưới dự phòng</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="383"/>
      <source>Deflection</source>
      <translation>Độ lệch</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="386"/>
      <source>deflection</source>
      <translation>độ lệch</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="393"/>
      <source>Triangulation settings</source>
      <translation>Cài đặt tam giác</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="90"/>
      <source>If this is checked, Features will claim their children in the tree view</source>
      <translation>Nếu chọn ô này, các tính năng trong chế độ xem dạng cây sẽ được bao gồm trong các con của nó</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="73"/>
      <source>Print debug information in the Console</source>
      <translation>In thông tin gỡ lỗi trong Bảng điều khiển</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="47"/>
      <source>The path to the OpenSCAD executable</source>
      <translation>Đường dẫn đến tệp thực thi OpenSCAD</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="215"/>
      <source>Minimum angle for a fragment</source>
      <translation>Góc tối thiểu cho một đoạn</translation>
    </message>
    <message>
      <location filename="openscadprefs-base.ui" line="272"/>
      <source>Minimum size of a fragment</source>
      <translation>Kích thước tối thiểu của một đoạn</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD</name>
    <message>
      <location filename="OpenSCADCommands.py" line="149"/>
      <source>Convert Edges to Faces</source>
      <translation>Chuyển đổi các cạnh sang bề mặt</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="309"/>
      <source>Please select 3 objects first</source>
      <translation>Hãy chọn 3 đối tượng trước</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Unsupported Function</source>
      <translation>Chức năng không được hỗ trợ</translation>
    </message>
    <message>
      <location filename="importCSG.py" line="1226"/>
      <source>Press OK</source>
      <translation>Nhấn OK</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="347"/>
      <source>Add</source>
      <translation>Thêm mới</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="348"/>
      <source>Clear</source>
      <translation>Xóa</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="349"/>
      <source>as Mesh</source>
      <translation>như lưới</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="350"/>
      <source>Add OpenSCAD Element</source>
      <translation>Thêm phần tử OpenSCAD</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="423"/>
      <source>Perform</source>
      <translation>Thực hiện</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="424"/>
      <source>Mesh Boolean</source>
      <translation>Lưới Boolean</translation>
    </message>
    <message>
      <location filename="OpenSCADUtils.py" line="623"/>
      <source>Error all shapes must be either 2D or both must be 3D</source>
      <translation>Lỗi tất cả các hình dạng phải là 2D hoặc cả hai phải là 3D</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="102"/>
      <source>Unable to explode %s</source>
      <translation>Không thể kéo dài thêm %s</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
      <location filename="OpenSCADCommands.py" line="464"/>
      <source>Add OpenSCAD Element...</source>
      <translation>Thêm phần tử OpenSCAD...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="468"/>
      <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
      <translation>Thêm một phần tử OpenSCAD bằng cách nhập mã OpenSCAD và thực thi nhị phân OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
      <location filename="OpenSCADCommands.py" line="126"/>
      <source>Color Shapes</source>
      <translation>Hình dạng màu sắc</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="129"/>
      <source>Color Shapes by validity and type</source>
      <translation>Phân loại hình dạng màu theo giá trị và kiểu</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
      <location filename="OpenSCADCommands.py" line="146"/>
      <source>Convert Edges To Faces</source>
      <translation>Chuyển đổi các cạnh sang thành mặt</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
      <location filename="OpenSCADCommands.py" line="291"/>
      <source>Expand Placements</source>
      <translation>Mở rộng vị trí</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="294"/>
      <source>Expand all placements downwards the FeatureTree</source>
      <translation>Mở rộng tất cả các vị trí xuống dưới FeatureTree</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
      <location filename="OpenSCADCommands.py" line="110"/>
      <source>Explode Group</source>
      <translation>Nhóm tháo rời</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="113"/>
      <source>Remove fusion, apply placement to children, and color randomly</source>
      <translation>Loại bỏ sáp nhập, áp dụng vị trí cho sản phẩm và tô màu một cách ngẫu nhiên</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Hull</name>
    <message>
      <location filename="OpenSCADCommands.py" line="497"/>
      <source>Hull</source>
      <translation>Vỏ bọc</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="500"/>
      <source>Perform Hull</source>
      <translation>Xây dựng Vỏ bọc</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="274"/>
      <source>Increase Tolerance Feature</source>
      <translation>Tính năng tăng dung sai</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="277"/>
      <source>Create Feature that allows to increase the tolerance</source>
      <translation>Tạo tính năng cho phép tăng dung sai</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
      <location filename="OpenSCADCommands.py" line="477"/>
      <source>Mesh Boolean...</source>
      <translation>Lưới Boolean...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="481"/>
      <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
      <translation>Xuất các đối tượng dưới dạng lưới và sử dụng OpenSCAD để thực hiện thao tác boolean</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_Minkowski</name>
    <message>
      <location filename="OpenSCADCommands.py" line="516"/>
      <source>Minkowski</source>
      <translation>Minkowski</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="519"/>
      <source>Perform Minkowski</source>
      <translation>Thực hiện Minkowski</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="195"/>
      <source>Mirror Mesh Feature...</source>
      <translation>Chức năng mirror lưới...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="198"/>
      <source>Create Mirror Mesh Feature</source>
      <translation>Tạo lưới mirror</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="165"/>
      <source>Refine Shape Feature</source>
      <translation>Tính năng tinh chỉnh hình dạng</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="168"/>
      <source>Create Refine Shape Feature</source>
      <translation>Tạo tính năng tinh chỉnh hình dạng</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
      <location filename="OpenSCADCommands.py" line="324"/>
      <source>Remove Objects and their Children</source>
      <translation>Loại bỏ các đối tượng và sản phẩm của chúng</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="327"/>
      <source>Removes the selected objects and all children that are not referenced from other objects</source>
      <translation>Loại bỏ các đối tượng đã chọn và tất cả sản phẩm không được tham chiếu từ các đối tượng khác</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
      <location filename="OpenSCADCommands.py" line="312"/>
      <source>Replace Object</source>
      <translation>Thay thế đối tượng</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="315"/>
      <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
      <translation>Thay thế một đối tượng trong cây tính năng. Vui lòng chọn đối tượng cũ, mới và gốc</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="254"/>
      <source>Resize Mesh Feature...</source>
      <translation>Thay đổi kích cỡ lưới...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="258"/>
      <source>Create Resize Mesh Feature</source>
      <translation>Tạo chức năng thay đổi kích cỡ lưới</translation>
    </message>
  </context>
  <context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
      <location filename="OpenSCADCommands.py" line="224"/>
      <source>Scale Mesh Feature...</source>
      <translation>Chức năng phóng to lưới...</translation>
    </message>
    <message>
      <location filename="OpenSCADCommands.py" line="228"/>
      <source>Create Scale Mesh Feature</source>
      <translation>Tạo chức năng phóng to lưới</translation>
    </message>
  </context>
  <context>
    <name>Workbech</name>
    <message>
      <location filename="InitGui.py" line="83"/>
      <source>OpenSCAD Part tools</source>
      <translation>Công cụ phần OpenSCAD</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="InitGui.py" line="81"/>
      <source>OpenSCADTools</source>
      <translation>Công cụ OpenSCAD</translation>
    </message>
  </context>
</TS>
